from .colors import Foreground, Util

minecraft_colors = {
    '0': Foreground.BLACK,
    '1': Foreground.BLUE,
    '2': Foreground.GREEN,
    '3': Foreground.CYAN,
    '4': Foreground.RED,
    '5': Foreground.MAGENTA,
    '6': Foreground.YELLOW,
    '7': Foreground.LIGHTBLACK_EX,
    '8': Util.DIM + Foreground.LIGHTBLACK_EX,
    '9': Foreground.LIGHTBLUE_EX,
    'a': Foreground.LIGHTGREEN_EX,
    'b': Foreground.LIGHTCYAN_EX,
    'c': Foreground.LIGHTRED_EX,
    'd': Util.BOLD + Foreground.LIGHTMAGENTA_EX,
    'e': Foreground.LIGHTYELLOW_EX,
    'f': Foreground.WHITE,
}

minecraft_formatting = {
    'k': '',
    'l': Util.BOLD,
    'm': Util.STRIKETHROUGH,
    'n': Util.UNDERLINE,
    'o': Util.ITALIC,
    'r': Util.RESET_ALL,
    'x': ''
}



from .mc import minecraft_colors, minecraft_formatting


def mcwrite(text, reset_all=True):
    """
    Allows you to write with colors in 
    the terminal using the color codes

    :param text: Text
    :param reset_all: Boolean value that decides whether to reset the text color at the end.
    """

    for code, color_code in minecraft_colors.items():
        text = text.replace(f'&{code}', f'&r{color_code}'
                    ).replace(f'§{code}', f'&r{color_code}')

    for code, format_code in minecraft_formatting.items():
        text = text.replace(f'&{code}', format_code
                    ).replace(f'§{code}', format_code)

    if reset_all:
        text += '\033[0m'

    print(text)
    return text


def mcreplace(text, reset_all=True):
    """
    Allows you to replace the color codes
    with their respective colors.

    :param text: Text
    :param reset_all: Boolean value that decides whether to reset the text color at the end.
    :return: Colored text
    """

    for code, color_code in minecraft_colors.items():
        if f'&{code}' in text or f'§{code}' in text:
            text = text.replace(f'&{code}', f'&r{color_code}'
                        ).replace(f'§{code}', f'&r{color_code}')

    for code, format_code in minecraft_formatting.items():
        if f'&{code}' in text or f'§{code}' in text:
            text = text.replace(f'&{code}', format_code
                        ).replace(f'§{code}', format_code)

    if reset_all:
        text += '\033[0m'

    return text


def mcremove(text):
    """
    Allows you to remove color codes from a text.

    :param text: Text
    :return: Clean text
    """

    for code in minecraft_colors.keys():
        text = text.replace(f'&{code}', ''
                  ).replace(f'§{code}', '')

    for code in minecraft_formatting.keys():
        text = text.replace(f'&{code}', ''
                  ).replace(f'§{code}', '')
    
    return text



from setuptools import setup, find_packages


setup(
    name='mccolors',
    version='0.1',
    packages=find_packages(),
    description='A Python package for managing Minecraft-style colors in terminal output.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='wRRulos',
    author_email='vegapedroagustin@gmail.com',
    url='https://github.com/wrrulos/mccolors',
    license='MIT License',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    install_requires=[],
)
